@@ -19,15 +19,15 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <gtkmm/main.h>
+#include "gtkmm/main.h"
 #include "demowindow.h"
 
 int main (int argc, char *argv[])
 {
-  Glib::RefPtr<Gtk::Application> app =
-    Gtk::Application::create(argc, argv);
+  Gtk::Main kit(argc, argv);
 
   DemoWindow window;
 
-  return app->run(window);
+  kit.run(window);
+  return 0;
 }
