@@ -20,8 +20,7 @@ void on_object_qdata_destroyed(gpointer data)
 
 int main(int argc, char**argv)
 {
-  Glib::RefPtr<Gtk::Application> app =
-    Gtk::Application::create(argc, argv);
+  Gtk::Main app(&argc, &argv);
 
   Gtk::Dialog* pDialog = new Gtk::Dialog();
   Gtk::Box* pBox = pDialog->get_content_area();
@@ -29,7 +28,7 @@ int main(int argc, char**argv)
   //Set a quark and a callback:
   initialize_quark();
   int a = 0; // (This doesn't work unless we have a non-null value for the 3rd parameter.)
-  g_object_set_qdata_full((GObject*)pBox->gobj(), quark_test, &a, &on_object_qdata_destroyed);
+  g_object_set_qdata_full((GObject*)pBox->gobj(), quark_test, &a, &on_object_qdata_destroyed); 
 
   g_warning("vbox refcount=%d", G_OBJECT(pBox->gobj())->ref_count);
 
